CREATE TABLE `mo_report_base_info`
(
    `id`            int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `file_id`       int(11) NOT NULL,
    `report_date`   datetime     DEFAULT NULL COMMENT '报告日期',
    `report_name`   varchar(255) DEFAULT NULL COMMENT '报告名称',
    `report_type`   varchar(255) DEFAULT NULL COMMENT '报告类型',
    `with_contacts` tinyint(4) NOT NULL DEFAULT '0' COMMENT '观点报告是否存在管理人联系信息（包括联系电话、地址、姓名等敏感信息）',
    `isvalid`       int(11) DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效；',
    `creatorid`     int(11) DEFAULT NULL COMMENT '创建者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `updaterid`     int(11) DEFAULT NULL COMMENT '修改者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `createtime`    datetime     DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间,默认第一次创建的getdate()时间',
    `updatetime`    datetime     DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间;第一次创建时与CreatTime值相同，修改时与修改时间相同',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=68 DEFAULT CHARSET=utf8 COMMENT='报告基础信息表'

CREATE TABLE `mo_report_fund_info`
(
    `id`                        int(11) NOT NULL AUTO_INCREMENT COMMENT '主键，自动递增',
    `file_id`                   int(11) NOT NULL,
    `fund_name`                 varchar(255)   DEFAULT NULL COMMENT '基金的名称',
    `fund_code`                 varchar(50)    DEFAULT NULL COMMENT '基金的唯一识别代码',
    `company_name`              varchar(255)   DEFAULT NULL COMMENT '基金管理人的名称',
    `currency`                  varchar(20)    DEFAULT NULL COMMENT '基金交易使用的货币种类',
    `custodian_name`            varchar(255)   DEFAULT NULL COMMENT '基金托管人',
    `advisor_name`              varchar(255)   DEFAULT NULL COMMENT '投资顾问',
    `operation_type`            varchar(20)    DEFAULT NULL COMMENT '基金运作方式',
    `inception_date`            date           DEFAULT NULL COMMENT '基金成立日期',
    `investment_objective`      text COMMENT '投资目标',
    `fund_strategy_description` text COMMENT '投资策略',
    `secondary_benchmark`       varchar(255)   DEFAULT NULL COMMENT '业绩比较基准',
    `risk_return_desc`          text COMMENT '风险收益特征',
    `due_date`                  date           DEFAULT NULL COMMENT '基金到期日期',
    `reviewed`                  int(11) DEFAULT NULL COMMENT '信息披露报告是否经托管机构复核',
    `leverage`                  decimal(22, 6) DEFAULT NULL COMMENT '杠杆比例',
    `leverage_note`             text COMMENT '杠杆比例描述',
    `industry_trend`            text COMMENT '行业趋势',
    `fund_manager`              text COMMENT '基金经理描述',
    `isvalid`                   tinyint(4) NOT NULL DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效',
    `creatorid`                 int(11) NOT NULL COMMENT '创建者Id',
    `updaterid`                 int(11) NOT NULL COMMENT '修改者Id',
    `createtime`                datetime       DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updatetime`                datetime       DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=68 DEFAULT CHARSET=utf8 COMMENT='报告解析结果之基金信息表'

CREATE TABLE `mo_report_fund_transaction`
(
    `id`                        int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `file_id`                   int(11) NOT NULL,
    `fund_account`              varchar(100)   DEFAULT NULL COMMENT '基金账户编号',
    `fund_name`                 varchar(100)   DEFAULT NULL COMMENT '基金名称',
    `distributor`               varchar(100)   DEFAULT NULL COMMENT '销售此基金产品的经销商或银行',
    `transaction_type`          varchar(50)    DEFAULT NULL COMMENT '业务类型（例如：申购、赎回）',
    `business_reason`           varchar(100)   DEFAULT NULL COMMENT '业务操作的原因或类型说明',
    `status`                    varchar(50)    DEFAULT NULL COMMENT '交易确认的状态（例如：已确认、待处理等）',
    `holding_date`              date           DEFAULT NULL COMMENT '交易确认的日期',
    `apply_date`                date           DEFAULT NULL COMMENT '申请的日期',
    `apply_amount`              decimal(22, 6) DEFAULT NULL COMMENT '申请的金额',
    `apply_share`               decimal(22, 6) DEFAULT NULL COMMENT '申请的基金份额数量',
    `amount`                    decimal(22, 6) DEFAULT NULL COMMENT '确认的金额',
    `share`                     decimal(22, 6) DEFAULT NULL COMMENT '确认的基金份额数量',
    `net_amount`                decimal(22, 6) DEFAULT NULL COMMENT '净认购/申购的金额，确认净额',
    `nav`                       decimal(22, 6) DEFAULT NULL COMMENT '单位净值',
    `confirmation_ratio`        decimal(22, 6) DEFAULT NULL COMMENT '确认比例',
    `ta_confirmation_number`    varchar(100)   DEFAULT NULL COMMENT '交易授权确认编号',
    `ta_number`                 varchar(100)   DEFAULT NULL COMMENT 'TA代码',
    `apply_no`                  varchar(100)   DEFAULT NULL COMMENT '申请单号',
    `share_balance`             decimal(22, 6) DEFAULT NULL COMMENT '份额余额',
    `share_category`            varchar(50)    DEFAULT NULL COMMENT '份额类别',
    `large_redemption_type`     varchar(50)    DEFAULT NULL COMMENT '巨额赎回方式',
    `reward_mark`               varchar(50)    DEFAULT NULL COMMENT '提成或保底标志',
    `holding_days`              int(11) DEFAULT NULL COMMENT '持有天数',
    `share_registry_date`       date           DEFAULT NULL COMMENT '份额明细注册日期',
    `fee`                       decimal(22, 6) DEFAULT NULL COMMENT '总费用',
    `interest`                  decimal(22, 6) DEFAULT NULL COMMENT '利息',
    `interest_to_fund_assets`   decimal(22, 6) DEFAULT NULL COMMENT '利息转份额/利息归基金资产',
    `trade_fee`                 decimal(22, 6) DEFAULT NULL COMMENT '交易费',
    `default_fee`               decimal(22, 6) DEFAULT NULL COMMENT '违约金',
    `performance_fee`           decimal(22, 6) DEFAULT NULL COMMENT '业绩报酬',
    `fee_discounts`             decimal(22, 6) DEFAULT NULL COMMENT '费用折扣',
    `performance_fee_discounts` decimal(22, 6) DEFAULT NULL COMMENT '业绩报酬折扣',
    `dividend_type`             varchar(50)    DEFAULT NULL COMMENT '分红方式',
    `dividend_registry_date`    date           DEFAULT NULL COMMENT '分红登记日',
    `dividend_payment_date`     date           DEFAULT NULL COMMENT '红利发放日',
    `base_share_dividend`       decimal(22, 6) DEFAULT NULL COMMENT '分红基数份额',
    `dividend_mode`             varchar(50)    DEFAULT NULL COMMENT '分红模式',
    `unit_dividend`             decimal(22, 6) DEFAULT NULL COMMENT '单位分红',
    `dividend_per_unit`         decimal(22, 6) DEFAULT NULL COMMENT '每单位分红',
    `total_dividend_amount`     decimal(22, 6) DEFAULT NULL COMMENT '红利总额',
    `actual_cash_dividend`      decimal(22, 6) DEFAULT NULL COMMENT '实发现金红利',
    `frozen_shares`             decimal(22, 6) DEFAULT NULL COMMENT '冻结份额',
    `frozen_amount`             decimal(22, 6) DEFAULT NULL COMMENT '冻结金额',
    `actual_performance_amount` decimal(22, 6) DEFAULT NULL COMMENT '实际业绩提成金额',
    `actual_performance_share`  decimal(22, 6) DEFAULT NULL COMMENT '实际提成份额',
    `isvalid`                   int(11) DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效；',
    `creatorid`                 int(11) DEFAULT NULL COMMENT '创建者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `updaterid`                 int(11) DEFAULT NULL COMMENT '修改者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `createtime`                datetime       DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间,默认第一次创建的getdate()时间',
    `updatetime`                datetime       DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间;第一次创建时与CreatTime值相同，修改时与修改时间相同',
    `is_sync`                   tinyint(3) NOT NULL DEFAULT '0' COMMENT '是否同步(0-否；1-是)',
    PRIMARY KEY (`id`),
    KEY                         `file_id` (`file_id`)
) ENGINE=InnoDB AUTO_INCREMENT=45 DEFAULT CHARSET=utf8 COMMENT='交易流水表'

CREATE TABLE `mo_report_invest_industry`
(
    `id`            int(11) NOT NULL AUTO_INCREMENT,
    `file_id`       int(11) NOT NULL,
    `invest_type`   int(11) DEFAULT NULL COMMENT '投资地区: 1-境内, 2-港股通',
    `isb_code`      varchar(255)   DEFAULT NULL COMMENT '行业标准编码',
    `industry_code` varchar(255)   DEFAULT NULL COMMENT '行业分类编码',
    `industry_name` varchar(255)   DEFAULT NULL COMMENT '行业分类名称',
    `market_value`  decimal(22, 6) DEFAULT NULL COMMENT '公允价值',
    `ratio`         decimal(22, 6) DEFAULT NULL COMMENT '占基金资产净值的比例',
    `isvalid`       int(11) DEFAULT '1' COMMENT '是否有效：0-无效，1-有效',
    `creatorid`     int(11) DEFAULT NULL COMMENT '创建者Id',
    `createtime`    datetime       DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updaterid`     int(11) DEFAULT NULL COMMENT '修改者Id',
    `updatetime`    datetime       DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `INVEST_INDUSTRY_UIX_KEY` (`file_id`,`invest_type`,`isb_code`,`industry_code`,`industry_name`)
) ENGINE=InnoDB AUTO_INCREMENT=41 DEFAULT CHARSET=utf8 COMMENT='按行业分类的股票投资组合'

CREATE TABLE `mo_report_investor_info`
(
    `id`                 int(11) NOT NULL AUTO_INCREMENT COMMENT '主键，自动递增',
    `file_id`            int(11) NOT NULL,
    `investor_name`      varchar(255) DEFAULT NULL COMMENT '投资人的姓名',
    `investor_type`      varchar(50)  DEFAULT NULL COMMENT '投资人的类别（例如：个人、机构）',
    `certificate_type`   varchar(50)  DEFAULT NULL COMMENT '证件类型（例如：身份证、护照）',
    `certificate_number` varchar(50)  DEFAULT NULL COMMENT '投资人证件号码',
    `fund_account`       varchar(50)  DEFAULT NULL COMMENT '基金账户编号',
    `trading_account`    varchar(50)  DEFAULT NULL COMMENT '投资者交易账号',
    `isvalid`            tinyint(4) NOT NULL DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效',
    `creatorid`          int(11) NOT NULL COMMENT '创建者Id',
    `updaterid`          int(11) NOT NULL COMMENT '修改者Id',
    `createtime`         datetime     DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updatetime`         datetime     DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`),
    KEY                  `file_id` (`file_id`)
) ENGINE=InnoDB AUTO_INCREMENT=45 DEFAULT CHARSET=utf8 COMMENT='报告解析结果之投资者信息表'

CREATE TABLE `mo_report_net_report`
(
    `id`               int(11) NOT NULL AUTO_INCREMENT,
    `file_id`          int(11) NOT NULL,
    `level`            varchar(20)    DEFAULT NULL COMMENT '基金分级',
    `valuation_date`   date           DEFAULT NULL COMMENT '估值日期',
    `nav`              decimal(22, 6) DEFAULT NULL COMMENT '单位净值',
    `cumulative_nav`   decimal(22, 6) DEFAULT NULL COMMENT '累计净值',
    `end_total_shares` decimal(22, 6) DEFAULT NULL COMMENT '基金份额总额',
    `fund_asset_size`  decimal(22, 6) DEFAULT NULL COMMENT '基金资产净值',
    `isvalid`          int(11) DEFAULT '1' COMMENT '是否有效：0-无效，1-有效',
    `creatorid`        int(11) DEFAULT NULL COMMENT '创建者Id',
    `createtime`       datetime       DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updaterid`        int(11) DEFAULT NULL COMMENT '修改者Id',
    `updatetime`       datetime       DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `NET_REPORT_UIX_KEY` (`file_id`,`level`)
) ENGINE=InnoDB AUTO_INCREMENT=17 DEFAULT CHARSET=utf8 COMMENT='基协报告净值月报'

CREATE TABLE `mo_report_share_change`
(
    `id`                int(11) NOT NULL AUTO_INCREMENT,
    `file_id`           int(11) NOT NULL,
    `level`             varchar(20)    DEFAULT NULL COMMENT '基金分级',
    `init_total_shares` decimal(22, 6) DEFAULT NULL COMMENT '报告期期初基金份额总额',
    `subscription`      decimal(22, 6) DEFAULT NULL COMMENT '报告期期间基金总申购份额',
    `redemption`        decimal(22, 6) DEFAULT NULL COMMENT '减: 报告期期间基金总赎回份额',
    `split`             decimal(22, 6) DEFAULT NULL COMMENT '报告期期间基金拆分变动份额',
    `share_per_asset`   decimal(22, 6) DEFAULT NULL COMMENT '期末基金总份额/期末基金实缴总额',
    `isvalid`           int(11) DEFAULT '1' COMMENT '是否有效：0-无效，1-有效',
    `creatorid`         int(11) DEFAULT NULL COMMENT '创建者Id',
    `createtime`        datetime       DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updaterid`         int(11) DEFAULT NULL COMMENT '修改者Id',
    `updatetime`        datetime       DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `UIX_KEY` (`file_id`,`level`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COMMENT='基金份额变动情况'

CREATE TABLE `mo_report_financial_indicators`
(
    `id`                   int(11) NOT NULL AUTO_INCREMENT,
    `file_id`              int(11) NOT NULL,
    `level`                varchar(50)    DEFAULT NULL COMMENT '基金分级',
    `end_date`             int(11) DEFAULT NULL COMMENT '年度',
    `realized_income`      decimal(22, 6) DEFAULT NULL COMMENT '本期已实现收益',
    `profit`               decimal(22, 6) DEFAULT NULL COMMENT '本期利润',
    `undistributed_profit` decimal(22, 6) DEFAULT NULL COMMENT '期末可供分配利润',
    `fund_asset_size`      decimal(22, 6) DEFAULT NULL COMMENT '期末基金净资产',
    `nav`                  decimal(22, 6) DEFAULT NULL COMMENT '报告期期末单位净值',
    `isvalid`              int(11) DEFAULT '1' COMMENT '是否有效：0-无效，1-有效',
    `creatorid`            int(11) DEFAULT NULL COMMENT '创建者Id',
    `createtime`           datetime       DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updaterid`            int(11) DEFAULT NULL COMMENT '修改者Id',
    `updatetime`           datetime       DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `UNIQUE_FINANCIAL_INDICATORS` (`file_id`,`level`,`end_date`)
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8 COMMENT='报告主要财务指标'

CREATE TABLE `mo_report_asset_allocation`
(
    `id`           int(11) NOT NULL AUTO_INCREMENT,
    `file_id`      int(11) NOT NULL,
    `asset_type`   varchar(255)   DEFAULT NULL COMMENT '资产类别',
    `column_name`  varchar(255)   DEFAULT NULL COMMENT '统计列名',
    `market_value` decimal(22, 6) DEFAULT NULL COMMENT '金额(元)',
    `remark`       varchar(50)    DEFAULT NULL COMMENT '备注',
    `isvalid`      int(11) DEFAULT '1' COMMENT '是否有效：0-无效，1-有效',
    `creatorid`    int(11) DEFAULT NULL COMMENT '创建者Id',
    `createtime`   datetime       DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updaterid`    int(11) DEFAULT NULL COMMENT '修改者Id',
    `updatetime`   datetime       DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `ASSET_ALLOCATION_UIX_KEY` (`file_id`,`asset_type`,`column_name`,`market_value`,`remark`)
) ENGINE=InnoDB AUTO_INCREMENT=64 DEFAULT CHARSET=utf8 COMMENT='基金资产组合情况'

CREATE TABLE `mo_mailbox_info`
(
    `id`          int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `type`        int(11) DEFAULT NULL COMMENT '邮箱类型:1-QQ邮箱,2-腾讯企业邮箱,3-网易邮箱,4-新浪邮箱,99-其他',
    `email`       varchar(255) DEFAULT NULL COMMENT '邮箱账号',
    `password`    varchar(255) DEFAULT NULL COMMENT '邮箱密码',
    `protocol`    varchar(255) DEFAULT NULL COMMENT '协议',
    `server`      varchar(255) DEFAULT NULL COMMENT '收件服务器',
    `port`        varchar(255) DEFAULT NULL COMMENT '端口',
    `cron`        varchar(255) DEFAULT NULL COMMENT 'cron表达式',
    `open_status` int(11) DEFAULT '0' COMMENT '是否开启，0-不开启，1-开启',
    `description` text COMMENT '备注信息',
    `isvalid`     int(11) DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效；',
    `creatorid`   int(11) DEFAULT NULL COMMENT '创建者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `updaterid`   int(11) DEFAULT NULL COMMENT '修改者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `createtime`  datetime     DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间,默认第一次创建的getdate()时间',
    `updatetime`  datetime     DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间;第一次创建时与CreatTime值相同，修改时与修改时间相同',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COMMENT='邮箱信息表'

CREATE TABLE `mo_email_file_info`
(
    `id`         int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `email_id`   int(11) NOT NULL COMMENT '邮件id',
    `fund_id`    int(11) DEFAULT NULL COMMENT '基金id',
    `file_name`  varchar(255)  NOT NULL COMMENT '附件名称',
    `file_path`  varchar(1024) NOT NULL COMMENT '附件路径',
    `ai_parse`   tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否利用ai工具来解析的',
    `ai_file_id` varchar(64) DEFAULT NULL COMMENT 'ai解析时上传的文件id（方便重新解析）',
    `isvalid`    tinyint(4) NOT NULL DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效',
    `creatorid`  int(11) NOT NULL COMMENT '创建者Id',
    `updaterid`  int(11) NOT NULL COMMENT '修改者Id',
    `createtime` datetime    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updatetime` datetime    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=175 DEFAULT CHARSET=utf8 COMMENT='邮件附件信息表'

CREATE TABLE `mo_email_parse_info`
(
    `id`           int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `sender_email` varchar(255) DEFAULT NULL COMMENT '邮件发送方',
    `email`        varchar(255) DEFAULT NULL COMMENT '邮箱地址',
    `email_key`    varchar(64)  DEFAULT NULL,
    `email_date`   datetime     DEFAULT NULL COMMENT '邮箱日期',
    `parse_date`   datetime     DEFAULT NULL COMMENT '解析日期',
    `email_title`  varchar(255) DEFAULT NULL COMMENT '邮件主题',
    `email_type`   int(11) DEFAULT NULL,
    `parse_status` int(11) DEFAULT NULL COMMENT '解析状态',
    `fail_reason`  text COMMENT '失败原因',
    `attr_size`    int(11) DEFAULT NULL COMMENT '附件文件大小，byte',
    `isvalid`      int(11) DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效；',
    `creatorid`    int(11) DEFAULT NULL COMMENT '创建者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `updaterid`    int(11) DEFAULT NULL COMMENT '修改者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `createtime`   datetime     DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间,默认第一次创建的getdate()时间',
    `updatetime`   datetime     DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间;第一次创建时与CreatTime值相同，修改时与修改时间相同',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=82 DEFAULT CHARSET=utf8 COMMENT='邮件解析信息表'

CREATE TABLE `mo_email_field_mapping`
(
    `id`         int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `code`       varchar(255) DEFAULT NULL COMMENT '字段编码',
    `name`       text COMMENT '字段(多个以英文逗号隔开)',
    `type`       int(11) DEFAULT NULL COMMENT '3-定期报告，4-交易流水确认函，0-共用的',
    `isvalid`    int(11) DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效；',
    `creatorid`  int(11) DEFAULT NULL COMMENT '创建者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `updaterid`  int(11) DEFAULT NULL COMMENT '修改者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `createtime` datetime     DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间,默认第一次创建的getdate()时间',
    `updatetime` datetime     DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间;第一次创建时与CreatTime值相同，修改时与修改时间相同',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=89 DEFAULT CHARSET=utf8 COMMENT='邮件字段映射表'

CREATE TABLE `mo_task_record`
(
    `id`         int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `task_key`   varchar(50) NOT NULL COMMENT '任务的标识',
    `start_time` datetime DEFAULT NULL COMMENT '任务开始执行的时间',
    `end_time`   datetime DEFAULT NULL COMMENT '任务执行结束时的时间',
    `status`     int(4) DEFAULT '0' COMMENT '任务执行状态，0-执行中，1-执行完成，2-执行失败',
    `err_msg`    text COMMENT '任务执行失败时的信息',
    `createtime` datetime DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间,默认第一次创建的getdate()时间',
    `updatetime` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间;第一次创建时与CreatTime值相同，修改时与修改时间相同',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=284 DEFAULT CHARSET=utf8 COMMENT='任务执行记录表（轮询任务的执行记录表，前面的任务未执行完成时不允许重复执行）'



INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('fundName', '基金名称,产品名称', 0, 1, null, null, '2025-02-20 15:54:06', '2025-02-20 15:54:06');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('fundCode', '产品代码,基金代码', 0, 1, null, null, '2025-02-20 15:54:06', '2025-02-20 15:54:06');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('companyName', '管理人,基金管理人', 0, 1, null, null, '2025-02-20 15:54:06', '2025-02-20 15:54:06');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('currency', '币种,货币种类', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-20 16:05:35');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('investorName', '投资人,客户名称,投资者名称,投资者姓名,投资者,投资人名称,委托人名称,委托人姓名', 4, 1, null, null, '2025-02-20 16:05:35', '2025-03-18 16:07:36');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('investorType', '投资人类别,投资者类型,投资人类型', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-22 09:18:54');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('certificateType', '证件类型,投资者证件类型', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-20 16:05:35');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('certificateNumber', '证件号码,投资者证件号码', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-20 16:05:35');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('fundAccount', '基金账号,投资者基金账号', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-20 16:05:35');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('tradingAccount', '交易账号,投资者交易账号', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-20 16:05:35');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('distributor', '销售商,销售机构', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-20 16:05:35');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('nav', '单位净值,再投资单位净值,期末单位净值', 0, 1, null, null, '2025-02-20 17:17:20', '2025-02-22 09:41:48');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('transactionType', '业务类型,业务代码,业务类别', 4, 1, null, null, '2025-02-20 18:07:51', '2025-03-11 18:32:56');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('businessReason', '业务类型原因,失败原因,原因', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('status', '确认状态', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('holdingDate', '确认日期,交易确认日期', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('applyDate', '申请日期', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('applyAmount', '申请的金额,申请金额,申请金额(元)', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-22 11:04:39');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('applyShare', '申请的份额,申请份额,申请的基金份额数量', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('amount', '确认的金额,确认金额,确认金额(元),业绩报酬计提金额,再投资金额,再投资红利金额,原确认金额', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-22 11:04:39');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('share', '确认的份额,确认份额,扣减份额,再投资份额,持有份额', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-28 17:28:30');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('netAmount', '净认购/申购的金额,确认净额', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('fee', '交易费,手续费用,交易费(元),手续费用(元),总费用,总费用(元),再投资费用', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-22 11:04:38');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('confirmationRatio', '确认比例', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('taConfirmationNumber', 'TA确认号,TA确认编号,确认单号,TA确认单号', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-22 11:04:38');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('interest', '利息,利息(元)', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-22 11:04:38');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('interestToFundAssets', '利息转份额,利息归基金资产', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('applyNo', '申请单号', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('shareBalance', '份额余额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('shareCategory', '份额类别', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('largeRedemptionType', '巨额赎回方式', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('tradeFee', '交易费,交易费(元)', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('defaultFee', '违约金,违约金(元)', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('performanceFee', '业绩报酬,业绩报酬(元)', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('feeDiscounts', '费用折扣', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('performanceFeeDiscounts', '业绩报酬折扣', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('dividendRegistryDate', '分红登记日', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('dividendPaymentDate', '红利发放日,红利下发日', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('baseShareDividend', '分红基数份额,分红总份额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('dividendMode', '分红模式', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('unitDividend', '单位分红', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('dividendPerUnit', '每单位分红', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('totalDividendAmount', '红利总额,分红总金额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('actualCashDividend', '实发现金红利,实际所得现金红利', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('frozenShares', '冻结份额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('frozenAmount', '冻结金额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('actualPerformanceAmount', '实际业绩提成金额,实际提成金额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('actualPerformanceShare', '实际提成份额,实际业绩提成份额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('rewardMark', '提成或保底标志', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('holdingDays', '持有天数', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('shareRegistryDate', '份额明细注册日期', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('taNumber', 'TA代码', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('dividendType', '分红方式', 4, 1, null, null, '2025-02-22 13:41:57', '2025-02-28 17:30:31');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('advisorName', '投资顾问(如有),投资顾问,投资顾问（如有）', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('custodianName', '基金托管人,基金托管人(如有),基金托管人（如有）', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('fundManager', '基金经理', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('fundStrategyDescription', '投资策略', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('inceptionDate', '成立日期,基金成立日期', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('industryTrend', '行业趋势', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('investmentObjective', '投资目标', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('leverage', '杠杆比例', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('leverageNote', '杠杆比例描述', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('operationType', '运作方式,基金运作方式', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('riskReturnDesc', '风险收益特征', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('secondaryBenchmark', '业绩比较基准,业绩比较基准(如有),业绩比较基准（如有）', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('companyName', '基金管理人,管理人', 3, 1, null, null, '2024-10-09 14:39:26', '2025-04-24 17:24:05');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('dueDate', '基金到期日期,到期日期', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('isReviewed', '信息披露报告是否经托管机构复核', 3, 1, null, null, '2024-10-09 14:39:26', '2024-10-09 14:39:26');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('level', '基金分级,分级,分级基金', 3, 1, null, null, '2024-10-09 14:45:05', '2024-10-09 14:45:05');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('valuationDate', '估值日期', 3, 1, null, null, '2024-10-09 14:45:05', '2024-10-09 14:45:05');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('assetShare', '基金份额总额,基金份额总额(份),基金总份额', 3, 1, null, null, '2024-10-09 17:18:05', '2025-04-23 17:31:27');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('assetNet', '基金资产净值,资产净值,总资产净值,资产净值元,总净值,规模,子产品基金规模,产品资产净值,基金总净值,基金总净值元,资产净值市值,基金净资产,期末基金净资产,期末基金资产净值', 3, 1, null, null, '2024-10-09 17:26:00', '2024-10-09 17:26:00');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('undistributedProfit', '期末可供分配利润', 3, 1, null, null, '2024-10-10 14:13:49', '2024-10-10 14:13:49');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('realizedIncome', '本期已实现收益', 3, 1, null, null, '2024-10-10 14:13:49', '2024-10-10 14:13:49');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('profit', '本期利润', 3, 1, null, null, '2024-10-10 14:13:49', '2024-10-10 14:13:49');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('yearly', '年度', 3, 1, null, null, '2024-10-10 14:13:49', '2024-10-10 14:13:49');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('initTotalShares', '报告期期初基金份额总额', 3, 1, null, null, '2024-10-10 14:13:49', '2024-10-10 14:13:49');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('redemption', '减:报告期期间基金总赎回份额,减报告期期间基金总赎回份额,报告期期间基金总赎回份额', 3, 1, null, null, '2024-10-10 14:13:49', '2025-04-12 16:48:27');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('sharePerAsset', '期末基金总份额/期末基金实缴总额,报告期期末基金份额总额', 3, 1, null, null, '2024-10-10 14:13:49', '2024-10-10 14:13:49');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('splitChangeShare', '报告期期间基金拆分变动份额', 3, 1, null, null, '2024-10-10 14:13:49', '2024-10-10 14:13:49');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('subscription', '报告期期间基金总申购份额', 3, 1, null, null, '2024-10-10 14:13:49', '2024-10-10 14:13:49');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('shareNavRet', '基金份额累计净值增长率', 3, 1, null, null, '2024-10-11 11:04:47', '2024-10-11 11:04:47');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('undistributedShareProfit', '期末可供分配基金份额利润', 3, 1, null, null, '2024-10-11 11:04:47', '2024-10-11 11:04:47');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('fundName', '基金名称,产品名称,产品全称,基金产品,名称,资产名称,账户名称,账套名称,子产品名称,项目名称', 3, 1, null, null, '2024-10-15 15:57:55', '2024-10-15 15:57:55');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('fundCode', '备案编码,协会备案编号,协会备案编码,协会备案代码,基金协会代码,产品编码,产品代码,产品备案号,产品备案编码,基金代码,基金编码,资产代码,代码,子产品代码,协会代码,基金编号', 3, 1, null, null, '2024-10-15 15:58:26', '2025-04-12 11:41:01');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('nav', '单位净值,单位净值元,当日单位净值,今日单位净值,计提前单位净值,实际净值,基金净值,资产份额净值,资产份额净值元,份额净值,基金份额净值,基金份额净值元,基金单位净值,虚拟净值提取前单位净值,报告期期末单位净值,虚拟计提前单位净值,试算前单位净值,期末单位净值,子产品单位净值,产品单位净值,本级别单位净值,委托资产份额净值元,期末基金份额净值', 3, 1, null, null, '2024-10-15 15:58:43', '2024-10-15 15:58:43');
INSERT INTO rz_market_operate_ppwfund.mo_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('cumulativeNavWithdrawal', '累计净值,累计净值元,累计单位净值,累计单位净值元,虚拟计提前累计单位净值,虚拟计提前累计净值,虚拟净值提取前累计单位净值,基金份额累计净值,计提前累计净值,报告期期末单位累计净值,实际累计净值,资产份额累计净值,资产份额累计净值元,期末累计净值,当日累计净值,基金份额累计单位净值,基金累计单位净值,产品累计单位净值,累计后单位净值,单位累计净值,基金累计净值,试算前累计单位净值,子产品累计净值,本级别累计单位净值,委托资产份额累计净值元,基金份额累计净值元,份额累计净值', 3, 1, null, null, '2024-10-15 15:59:44', '2024-10-15 15:59:44');

